local L = LibStub ("AceLocale-3.0"):GetLocale("ChatWheel", true)
ChatWheel.optionsTable = { 
    name = "ChatWheel",
    type = "group",
    handler = ChatWheel,
    args = {

        keyBind = {
            order = 3,
            type = "keybinding",
            name = L["Binded Key"],
            desc = "123",
            get = "getBindedKey",
            set = "setBindedKey",
        },
        group1 = { 
            type = "group",
            order = 2,
            name = L["Message Setting"],
            guiInline = true,
            args = {
                deleteExecute = {
                    order = 5,
                    type = "execute",
                    name = L["Delete"],
                    func = "doDelete",
                },
                saveExecute = {
                    order = 4,
                    type = "execute",
                    name = L["Save"],
                    func = "doSave",
                },
                saveName = {
                    order = 3,
                    type = "input",
                    name = L["Setting Name"],
                    get = "getSaveName",
                    set = "setSaveName",
                },
                messageTable = {
                    order = 2,
                    type = "input",
                    name = L["Current Setting"],
                    multiline = 8,
                    width = "full",
                    get = "getMessageTable",
                    set = "setMessageTable",
                },
                selectSaved = {
                    order = 1,
                    type = "select",
                    name = L["Saved Setting"],
                    values = {},
                    set = "setSaved",
                }
            }
        },
        channel = {
            order = 1,
            type = "select",
            name = L["Channel"],
            values = {
                PARTY = L["Party"],
                SAY = L["Say"]
            },
            get = "getChannel",
            set = "setChannel",
        }
    }
}

function ChatWheel:ValidateKey(key)
	return ( key and ( not key:lower():match('button') ) ) and key
end

function ChatWheel:getBindedKey()
    return ChatWheel.Args.db.global.bindedkey
end

function ChatWheel:setBindedKey(info, newValue)
    local newValue = ChatWheel:ValidateKey(newValue)
    ChatWheel.Args.db.global.bindedkey = newValue
    SetBinding(ChatWheel.Args.db.global.bindedkey, "SHOW_WHELL");
end

function ChatWheel:getMessageTable()
    return ChatWheel.Args.db.global.MessageTableStr
end

function ChatWheel:setMessageTable(info, newValue)
    local i = 1
    ChatWheel.Args.db.global.MessageTableStr = newValue
    for line in string.gmatch(newValue,'[^\r\n]+') do
        if i < 9 then
            if string.match(line, ".%-.") then
                ChatWheel.Args.db.global.MessageTable[i] = line
            else
                ChatWheel:Print(L["Wrong Message Patern"]..": "..line)
                ChatWheel.Args.db.global.MessageTable[i] = nil
            end
            ChatWheel.GUI:SetWheelMessage(i)
        else
            ChatWheel:Print(L["Too Many Lines"]..line)
        end
        i = i + 1
    end
    for i = i, 8, 1 do
        ChatWheel.Args.db.global.MessageTable[i] = nil
        ChatWheel.GUI:SetWheelMessage(i)
    end
end

function ChatWheel:getChannel()
    return ChatWheel.Args.db.global.Channel
end

function ChatWheel:setChannel(info, newValue)
    ChatWheel.Args.db.global.Channel = newValue
end

function ChatWheel:getSaveName()
    return ChatWheel.Args.saveName
end

function ChatWheel:setSaveName(info, newValue)
    ChatWheel.Args.saveName = newValue
end

function ChatWheel:setSaved(info, newValue)
    ChatWheel.Args.curSelectedSaveName = newValue
    local str = ChatWheel.Args.db.global.SavedTable[newValue]
    ChatWheel:setMessageTable(nil, str)
end


function ChatWheel:doSave()
    if not ChatWheel.Args.saveName then
        ChatWheel:Print(L["Please Input Name"])
    else
        ChatWheel.Args.db.global.SavedTable[ChatWheel.Args.saveName] = ChatWheel.Args.db.global.MessageTableStr
        ChatWheel.Args.db.global.SavedTableKeys[ChatWheel.Args.saveName] = ChatWheel.Args.saveName
    end
end

function ChatWheel:doDelete()
    if not ChatWheel.Args.saveName then
        ChatWheel:Print(L["Please Input Name"])
    else
        ChatWheel.Args.db.global.SavedTable[ChatWheel.Args.saveName] = nil
        ChatWheel.Args.db.global.SavedTableKeys[ChatWheel.Args.saveName] = nil
        ChatWheel.optionsTable.args.group1.args.selectSaved.values[ChatWheel.Args.saveName] = nil
    end
end


LibStub("AceConfig-3.0"):RegisterOptionsTable("ChatWheel", ChatWheel.optionsTable)
LibStub("AceConfigDialog-3.0"):AddToBlizOptions("ChatWheel", "ChatWheel")